/*
 * Copyright 2001-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.juddi.monitor;

import org.apache.juddi.datatype.RegistryObject;

/**
 * @author Anou Mana (anou_mana@users.sourceforge.net)
 */
public class MonitorData implements RegistryObject
{
  String requestURI       = "";  // initialize to empty string to avoid log db failure
  String remoteHost       = "";
  String calledFunction   = "";
  String authToken        = "";
  String uddiVersion      = "";
  String logTime          = null;
  String fault            = "";

  /**
   * Construct a new initialized MonitorData instance.
   */
  public MonitorData()
  {
  }

  /**
   * Construct a new MonitorData with a given user IP and the function called.
   *
   * @param remoteHost IP address of the host which initiated this request
   * @param calledFunction The UDDI or jUDDI function invoked by this request
   */
  public MonitorData(String remoteHost, String calledFunction)
  {
    this.remoteHost = remoteHost;
    this.calledFunction = calledFunction;
  }

  /**
   * @return The UDDI or jUDDI function invoked by this request.
   */
  public String getCalledFunction()
  {
    return calledFunction;
  }

  /**
   * @return The fault generated by the request (if it was unsuccessful)
   */
  public String getFault()
  {
    return fault;
  }

  /**
   * @return The time the request was logged
   */
  public String getLogTime()
  {
    return logTime;
  }

  /**
   * @return Version of the UDDI or jUDDI API used to make the request.
   */
  public String getVersion()
  {
    return uddiVersion;
  }

  /**
   * @return The AuthToken (if any) used to make the request.
   */
  public String getAuthToken()
  {
    return authToken;
  }

  /**
   * @param string
   */
  public void setCalledFunction(String string)
  {
    calledFunction = string;
  }

  /**
   * @param string
   */
  public void setFault(String string)
  {
    fault = string;
  }

  /**
   * @param string
   */
  public void setLogTime(String string)
  {
    logTime = string;
  }

  /**
   * @param ver
   */
  public void setUddiVersion(String ver)
  {
    uddiVersion = ver;
  }

  /**
   * @param authToken
   */
  public void setAuthToken(String authToken)
  {
    this.authToken = authToken;
  }

  /**
   * @return the name of the Host which made the request
   */
  public String getRemoteHost()
  {
    return remoteHost;
  }

  /**
   * @param host
   */
  public void setRemoteHost(String host)
  {
    remoteHost = host;
  }

  /**
   * @return the UDDI uri used to make the request
   */
  public String getRequestURI()
  {
    return requestURI;
  }

  /**
   * @param uri
   */
  public void setRequestURI(String uri)
  {
    requestURI = uri;
  }

  public String toString()
  {
    StringBuffer buff = new StringBuffer();
    buff.append(" RequestURI :" + requestURI);
    buff.append(" RemoteHost :" + remoteHost);
    buff.append(" CalledFunction :" + calledFunction);
    buff.append(" AuthToken :" + authToken);
    buff.append(" LogTime :" + logTime);
    buff.append(" Fault in uddi :" + fault);

    return buff.toString();
  }
}
